summaryrefslogtreecommitdiffstats
path: root/src/ui/widget
diff options
context:
space:
mode:
authorJohan B. C. Engelen <jbc.engelen@swissonline.ch>2006-11-29 20:35:57 +0000
committerjohanengelen <johanengelen@users.sourceforge.net>2006-11-29 20:35:57 +0000
commit9e78ac488bd9589a9ed263a5b236c921c7dafc3d (patch)
tree51bd44e8bd0db6b70052e54023089f1171c50f62 /src/ui/widget
parentprevent compiling error on gettimeofday on mingw compiler (diff)
downloadinkscape-9e78ac488bd9589a9ed263a5b236c921c7dafc3d.tar.gz
inkscape-9e78ac488bd9589a9ed263a5b236c921c7dafc3d.zip
C++ Find dialog almost complete! (it works, but it is biiig now)
(bzr r2054)
Diffstat (limited to 'src/ui/widget')
-rw-r--r--src/ui/widget/entry.cpp14
-rw-r--r--src/ui/widget/entry.h20
2 files changed, 18 insertions, 16 deletions
diff --git a/src/ui/widget/entry.cpp b/src/ui/widget/entry.cpp
index 73a5edac1..6159b4fe5 100644
--- a/src/ui/widget/entry.cpp
+++ b/src/ui/widget/entry.cpp
@@ -20,14 +20,14 @@ namespace Inkscape {
namespace UI {
namespace Widget {
-Entry::Entry(Glib::ustring const &label, Glib::ustring const &tooltip)
- : _label(label, true), _entry(), _tooltips()
-{
- pack_start(_label);
- pack_start(_entry);
-
- _tooltips.set_tip(*this, tooltip);
+Entry::Entry( Glib::ustring const &label, Glib::ustring const &tooltip,
+ Glib::ustring const &suffix,
+ Glib::ustring const &icon,
+ bool mnemonic)
+ : Labelled(label, tooltip, new Gtk::Entry(), suffix, icon, mnemonic)
+{
}
+
} // namespace Widget
} // namespace UI
diff --git a/src/ui/widget/entry.h b/src/ui/widget/entry.h
index 3ed4d661e..06cb19bef 100644
--- a/src/ui/widget/entry.h
+++ b/src/ui/widget/entry.h
@@ -17,22 +17,24 @@
#include <gtkmm/tooltips.h>
#include <gtkmm/label.h>
#include <gtkmm/box.h>
+#include "labelled.h"
namespace Inkscape {
namespace UI {
namespace Widget {
-class Entry : public Gtk::HBox
+class Entry : public Labelled
{
public:
- Entry(Glib::ustring const &label, Glib::ustring const &tooltip);
-
- // TO DO: add methods to access _entry
-
-protected:
- Gtk::Tooltips _tooltips;
- Gtk::Label _label;
- Gtk::Entry _entry;
+ Entry( Glib::ustring const &label,
+ Glib::ustring const &tooltip,
+ Glib::ustring const &suffix = "",
+ Glib::ustring const &icon = "",
+ bool mnemonic = true);
+
+ // TO DO: add methods to access Gtk::Entry widget
+
+ Gtk::Entry* getEntry() {return (Gtk::Entry*)(_widget);};
};
} // namespace Widget